<?php
  define('DB_ADAPTER', 'mysqli'); 
  define('DB_HOST', '[[softdbhost]]'); 
  define('DB_USER', '[[softdbuser]]'); 
  define('DB_PASS', '[[softdbpass]]'); 
  define('DB_NAME', '[[softdb]]'); 
  define('DB_PERSIST', true); 
  define('TABLE_PREFIX', '[[dbprefix]]'); 
  define('DB_ENGINE', 'InnoDB'); 
  define('ROOT_URL', '[[softurl]]'); 
  define('DEFAULT_LOCALIZATION', '[[language]]'); 
  define('COOKIE_PATH', '/'); 
  define('DEBUG', false); 
  define('SEED', '[[seed]]'); 
  define('DB_CHARSET', 'utf8'); 
  return true;
?>