<?php

/**
  * Return installed version
  * 
  * This file contains the installed version of the product. If this version is different
  * from the version defined in 'version.php' it means that you have a code base to which
  * you didn't run the upgrade process or you've ran the upgrade process but it failed.
  *
  * @author Ignacio de Soto <ignacio.desoto@fengoffice.com>
  */

return '[[version]]'; 

?>